Index: content/browser/tab_contents/tab_contents.cc |
diff --git a/content/browser/tab_contents/tab_contents.cc b/content/browser/tab_contents/tab_contents.cc |
index 8aedfa7f9c46290c8475116fd9ad46800072ad3b..46a10a4372b1d4a9611b5809d291974d1959b89a 100644 |
--- a/content/browser/tab_contents/tab_contents.cc |
+++ b/content/browser/tab_contents/tab_contents.cc |
@@ -1623,10 +1623,11 @@ WebPreferences TabContents::GetWebkitPrefs() { |
WebPreferences web_prefs = |
RenderViewHostDelegateHelper::GetWebkitPrefs(profile, is_web_ui); |
// Force accelerated compositing and 2d canvas off for chrome: and |
// chrome-extension: pages. |
if (GetURL().SchemeIs(chrome::kChromeDevToolsScheme) || |
- GetURL().SchemeIs(chrome::kChromeUIScheme)) { |
+ GetURL().SchemeIs(chrome::kChromeUIScheme) || |
+ GetURL().SchemeIs(chrome::kAboutScheme)) { |
web_prefs.accelerated_compositing_enabled = false; |
web_prefs.accelerated_2d_canvas_enabled = false; |
} |
@@ -1623,10 +1623,11 @@ WebPreferences TabContents::GetWebkitPrefs() { |
WebPreferences web_prefs = |
RenderViewHostDelegateHelper::GetWebkitPrefs(profile, is_web_ui); |
- // Force accelerated compositing and 2d canvas off for chrome: and |
- // chrome-extension: pages. |
+ // Force accelerated compositing and 2d canvas off for chrome:, about: and |
+ // chrome-devtools: pages. |
if (GetURL().SchemeIs(chrome::kChromeDevToolsScheme) || |